==> was-plugin-4.5.4-sources.jar: com/xebialabs/deployit/plugin/was/contributor/StopStartContainer.java <==
package com.xebialabs.deployit.plugin.was.contributor;

import java.util.Set;
import com.google.common.base.Strings;
import com.google.common.collect.ImmutableMap;

import com.xebialabs.deployit.plugin.api.deployment.planning.Contributor;
import com.xebialabs.deployit.plugin.api.deployment.planning.DeploymentPlanningContext;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;
import com.xebialabs.deployit.plugin.api.deployment.specification.Deltas;
import com.xebialabs.deployit.plugin.api.deployment.specification.Operation;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Deployed;
import com.xebialabs.deployit.plugin.python.PythonDeploymentStep;
import com.xebialabs.deployit.plugin.was.container.WasContainer;
import com.xebialabs.deployit.plugin.was.util.ContainerRestartStrategy;

import static com.google.common.collect.Sets.newHashSet;
import static java.lang.String.format;

public class StopStartContainer {

    protected static final String STOP_SCRIPT_PROPERTY = "stopScript";
    protected static final String START_SCRIPT_PROPERTY = "startScript";
    protected static final String RESTART_SCRIPT_PROPERTY = "restartScript";
    protected static final String STOP_ORDER_PROPERTY = "stopOrder";
    protected static final String START_ORDER_PROPERTY = "startOrder";
    protected static final String RESTART_ORDER_PROPERTY = "restartOrder";
    public static final String CONTAINER_RESTART_STRATEGY = "containerRestartStrategy";

    /**
     * StopStartContainer#stopAndStartContainers contributor will add steps to restart(or stop/start) deployed container
     * if deployed has property 'containerRestartStrategy' with value set to RESTART or STOP_START.
     */
    @Contributor
    public void stopAndStartContainers(Deltas deltas, DeploymentPlanningContext ctx) {
        doStopAndStartContainers(deltas, ctx);
    }

    protected void doStopAndStartContainers(Deltas deltas, DeploymentPlanningContext ctx) {
        Set<WasContainer> stopStartContainers = newHashSet();
        Set<WasContainer> restartStartContainers = newHashSet();

        findContainers(deltas, stopStartContainers, restartStartContainers);
        for (WasContainer wasContainer : stopStartContainers) {
            addStep(STOP_SCRIPT_PROPERTY, STOP_ORDER_PROPERTY, "Stop", wasContainer, ctx);
            addStep(START_SCRIPT_PROPERTY, START_ORDER_PROPERTY, "Start", wasContainer, ctx);
        }

        for (WasContainer wasContainer : restartStartContainers) {
            if (hasRestartScript(wasContainer)) {
                addStep(RESTART_SCRIPT_PROPERTY, RESTART_ORDER_PROPERTY, "Restart", wasContainer, ctx);
            } else {
                addStep(STOP_SCRIPT_PROPERTY, RESTART_ORDER_PROPERTY, "Stop", wasContainer, ctx);
                addStep(START_SCRIPT_PROPERTY, RESTART_ORDER_PROPERTY, "Start", wasContainer, ctx);
            }
        }
    }

    protected void addStep(String scriptProperty, String orderProperty, String verb, WasContainer container, DeploymentPlanningContext ctx) {
        if (container.hasProperty(scriptProperty) && container.hasProperty(orderProperty)) {
            ctx.addStep(new PythonDeploymentStep(
                container.<Integer> getProperty(orderProperty),
                container.getCell(),
                container.<String> getProperty(scriptProperty),
                ImmutableMap.<String, Object> of("container", container),
                format("%s '%s'", verb, container.getName())));
        }
    }

    protected boolean hasRestartScript(WasContainer container) {
        return container.hasProperty(RESTART_SCRIPT_PROPERTY) && !Strings.isNullOrEmpty(container.<String>getProperty(RESTART_SCRIPT_PROPERTY));
    }

    protected void findContainers(Deltas deltas, Set<WasContainer> stopStartContainers, Set<WasContainer> restartStartContainers) {
        for (Delta delta : deltas.getDeltas()) {
            Deployed<?, ?> deployed = delta.getOperation() == Operation.DESTROY ? delta.getPrevious() : delta.getDeployed();
            if (deployed.getContainer() instanceof WasContainer) {
                WasContainer container = (WasContainer) deployed.getContainer();
                if (!addContainerDependingOnStrategy(deployed, container, stopStartContainers, restartStartContainers)) {
                    addContainerDependingOnStrategy(container, stopStartContainers, restartStartContainers);
                }
            }
        }

        restartStartContainers.removeAll(stopStartContainers); // stop_start takes precedence over restart
    }

    protected boolean addContainerDependingOnStrategy(WasContainer container, Set<WasContainer> stopStartContainers, Set<WasContainer> restartStartContainers) {
        return addContainerDependingOnStrategy(container, container, stopStartContainers, restartStartContainers);
    }

    protected boolean addContainerDependingOnStrategy(ConfigurationItem ci, WasContainer container, Set<WasContainer> stopStartContainers, Set<WasContainer> restartStartContainers) {
        if (hasContainerRestartStrategy(ci)) {
            if (isStopStartStrategy(ci)) {
                stopStartContainers.add(container);
                return true;
            } else if (isRestartStrategy(ci)) {
                restartStartContainers.add(container);
                return true;
            }
        }
        return false;
    }

    protected boolean hasContainerRestartStrategy(ConfigurationItem configurationItem) {
        return configurationItem.hasProperty(CONTAINER_RESTART_STRATEGY) && configurationItem.getProperty(CONTAINER_RESTART_STRATEGY) != ContainerRestartStrategy.NONE;
    }

    protected boolean isRestartStrategy(ConfigurationItem ci) {
        return ci.getProperty(CONTAINER_RESTART_STRATEGY) == ContainerRestartStrategy.RESTART;
    }

    protected boolean isStopStartStrategy(ConfigurationItem ci) {
        return ci.getProperty(CONTAINER_RESTART_STRATEGY) == ContainerRestartStrategy.STOP_START;
    }

}

==> was-plugin-5.0.0-sources.jar: com/xebialabs/deployit/plugin/was/contributor/StopStartContainer.java <==
package com.xebialabs.deployit.plugin.was.contributor;

import java.util.Set;

import com.google.common.base.Strings;
import com.google.common.collect.ImmutableMap;

import com.xebialabs.deployit.plugin.api.deployment.planning.Contributor;
import com.xebialabs.deployit.plugin.api.deployment.planning.DeploymentPlanningContext;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;
import com.xebialabs.deployit.plugin.api.deployment.specification.Deltas;
import com.xebialabs.deployit.plugin.api.deployment.specification.Operation;
import com.xebialabs.deployit.plugin.api.udm.Deployed;
import com.xebialabs.deployit.plugin.python.PythonDeploymentStep;
import com.xebialabs.deployit.plugin.was.container.WasContainer;
import com.xebialabs.deployit.plugin.was.util.ContainerRestartStrategy;

import static com.google.common.collect.Sets.newHashSet;
import static java.lang.String.format;

public class StopStartContainer {

    protected static final String STOP_SCRIPT_PROPERTY = "stopScript";
    protected static final String START_SCRIPT_PROPERTY = "startScript";
    protected static final String RESTART_SCRIPT_PROPERTY = "restartScript";
    protected static final String STOP_ORDER_PROPERTY = "stopOrder";
    protected static final String START_ORDER_PROPERTY = "startOrder";
    protected static final String RESTART_ORDER_PROPERTY = "restartOrder";
    public static final String CONTAINER_RESTART_STRATEGY = "containerRestartStrategy";

    /**
     * StopStartContainer#stopAndStartContainers contributor will add steps to restart(or stop/start) deployed container
     * if deployed has property 'containerRestartStrategy' with value set to RESTART or STOP_START.
     */
    @Contributor
    public static void stopAndStartContainers(Deltas deltas, DeploymentPlanningContext ctx) {
        StopStartContainer contributor = new StopStartContainer();
        contributor.doStopAndStartContainers(deltas, ctx);
    }

    protected void doStopAndStartContainers(Deltas deltas, DeploymentPlanningContext ctx) {
        Set<WasContainer> stopStartContainers = newHashSet();
        Set<WasContainer> restartStartContainers = newHashSet();

        findContainers(deltas, stopStartContainers, restartStartContainers);
        for (WasContainer wasContainer : stopStartContainers) {
            addStep(STOP_SCRIPT_PROPERTY, STOP_ORDER_PROPERTY, "Stop", wasContainer, ctx);
            addStep(START_SCRIPT_PROPERTY, START_ORDER_PROPERTY, "Start", wasContainer, ctx);
        }

        for (WasContainer wasContainer : restartStartContainers) {
            if (hasRestartScript(wasContainer)) {
                addStep(RESTART_SCRIPT_PROPERTY, RESTART_ORDER_PROPERTY, "Restart", wasContainer, ctx);
            } else {
                addStep(STOP_SCRIPT_PROPERTY, RESTART_ORDER_PROPERTY, "Stop", wasContainer, ctx);
                addStep(START_SCRIPT_PROPERTY, RESTART_ORDER_PROPERTY, "Start", wasContainer, ctx);
            }
        }
    }

    protected void addStep(String scriptProperty, String orderProperty, String verb, WasContainer container, DeploymentPlanningContext ctx) {
        if (container.hasProperty(scriptProperty) && container.hasProperty(orderProperty)) {
            ctx.addStep(new PythonDeploymentStep(
                container.<Integer> getProperty(orderProperty),
                container.getCell(),
                container.<String> getProperty(scriptProperty),
                ImmutableMap.<String, Object> of("container", container),
                format("%s '%s'", verb, container.getName())));
        }
    }

    protected boolean hasRestartScript(WasContainer container) {
        return container.hasProperty(RESTART_SCRIPT_PROPERTY) && !Strings.isNullOrEmpty(container.<String>getProperty(RESTART_SCRIPT_PROPERTY));
    }

    protected void findContainers(Deltas deltas, Set<WasContainer> stopStartContainers, Set<WasContainer> restartStartContainers) {
        for (Delta delta : deltas.getDeltas()) {
            Deployed<?, ?> deployed = delta.getOperation() == Operation.DESTROY ? delta.getPrevious() : delta.getDeployed();
            if (deployed.getContainer() instanceof WasContainer) {
                if (deployed.hasProperty(CONTAINER_RESTART_STRATEGY)) {
                    if (deployed.getProperty(CONTAINER_RESTART_STRATEGY) == ContainerRestartStrategy.STOP_START) {
                        stopStartContainers.add((WasContainer) deployed.getContainer());
                    } else if (deployed.getProperty(CONTAINER_RESTART_STRATEGY) == ContainerRestartStrategy.RESTART) {
                        restartStartContainers.add((WasContainer) deployed.getContainer());
                    }
                }
            }
        }

        restartStartContainers.removeAll(stopStartContainers); // stop_start takes precedence over restart
    }
}
